package com.huguesjohnson.jail.jailBreak;

/*
jailBreak - Package to launch Java Artificial Intelligence Library components
JailBreakMainFrame.java - Main window
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Rectangle;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.lang.String;
import javax.swing.JFrame;
import com.huguesjohnson.jail.jailBreak.JailBreakDesktopPane;
import com.huguesjohnson.jail.jailBreak.JailBreakMenu;
import com.huguesjohnson.jail.jailBreak.JailBreakStatusbar;
import com.huguesjohnson.jail.jailBreak.JailBreakUIConstants;
import com.huguesjohnson.jail.jailBreak.event.JailBreakEvent;
import com.huguesjohnson.jail.neuralNetwork.Layer;
import com.huguesjohnson.jail.neuralNetwork.NeuralNetwork;
import com.huguesjohnson.jail.neuralNetwork.Neuron;

/** class JailBreakMainFrame 
 * @author  Hugues Johnson
 */
public class JailBreakMainFrame extends JFrame{
    
    /** the path to the folder containing images for current theme */
    private String resourcePath;

    /** the path to the folder containing default images */
    private String defaultResourcePath;
    
    /** reference to the statusbar for this frame */
    private JailBreakStatusbar statusBar;
    
    /** reference to the toolbar for this frame */
    private JailBreakToolbar toolBar;

    /** reference to the menubar for this frame */
    private JailBreakMenu menuBar;
    
    /** reference to the desktop pane for this frame */
    private JailBreakDesktopPane desktopPane;

    /** Creates new JailBreakDesktopPane 
     * @param resourcePath path to the folder containing images for current theme 
     * @param defaultResourcePath path to the folder containing default images   
     */
    public JailBreakMainFrame(String resourcePath,String defaultResourcePath){
        super(JailBreakUIConstants.CAPTION_WINDOW);
        /* set the resource paths */
        this.resourcePath=resourcePath;
        this.defaultResourcePath=defaultResourcePath;
        this.setSize(JailBreakUIConstants.MAIN_FRAME_DEFAULT_WIDTH,JailBreakUIConstants.MAIN_FRAME_DEFAULT_HEIGHT);
        /* add the toolbar */
        this.toolBar=new JailBreakToolbar(resourcePath,defaultResourcePath) { public void sendEvent(JailBreakEvent event){ receiveActionEvent(event);}};
        this.getContentPane().add(this.toolBar,BorderLayout.NORTH);
        /* add the statusbar */
        this.statusBar=new JailBreakStatusbar(resourcePath,defaultResourcePath);
        this.getContentPane().add(this.statusBar,BorderLayout.SOUTH);
        /* add the desktop pane */
        this.desktopPane=new JailBreakDesktopPane(resourcePath,defaultResourcePath) { public void sendEvent(JailBreakEvent event){ receiveActionEvent(event);}};
        this.getContentPane().add(this.desktopPane,BorderLayout.CENTER);
        desktopPane.setVisible(true);
        /* add the menu */
        this.menuBar=new JailBreakMenu(resourcePath,defaultResourcePath){ public void sendEvent(JailBreakEvent event){ receiveActionEvent(event);}};
        this.setJMenuBar(this.menuBar);
        /* add listener for close event */
        addWindowListener(new WindowAdapter(){ public void windowClosing(WindowEvent e){closeWindow();}});
        /* center the window */
        Dimension screenDimension=Toolkit.getDefaultToolkit().getScreenSize();
        Rectangle windowDimension=this.getBounds();
        this.setLocation((screenDimension.width-windowDimension.width)/2,(screenDimension.height-windowDimension.height)/2);
    }

    /** shows or hides the menubar
     * @param flag true to make the component visible; false to make it invisible 
     */
    public final void setMenuBarVisible(boolean flag){
        this.menuBar.setVisible(flag);
    }

    /** shows or hides the statusbar
     * @param flag true to make the component visible; false to make it invisible 
     */
    public final void setStatusBarVisible(boolean flag){
        this.statusBar.setVisible(flag);
    }

    /** shows or hides the toolbar
     * @param flag true to make the component visible; false to make it invisible 
     */
    public final void setToolBarVisible(boolean flag){
        this.toolBar.setVisible(flag);
    }    
    
    /** shows or hides the object browser (tree)
     * @param flag true to make the component visible; false to make it invisible 
     */
    public final void setObjectBrowserVisible(boolean flag){
        this.desktopPane.setObjectBrowserVisible(flag);
    }    

    /** shows or hides the object browser (tree)
     * @param flag true to make the component visible; false to make it invisible 
     */
    public final void setObjectViewerVisible(boolean flag){
        this.desktopPane.setObjectViewerVisible(flag);
    }       

    /** shows or hides debug messages
     * @param flag true to make the component visible; false to make it invisible 
     */
    public final void setDebugMessageFrameVisible(boolean flag){
        this.desktopPane.setDebugMessageFrameVisible(flag);
    }      
    
    /** writes a message to the debug frame
     * @param message the message to append to the debug frame
     */
    public void writeDebugMessage(String message){
        this.desktopPane.writeDebugMessage(message);
    }        
    
    /** updates the window based on the object passed
     * @param network a neural network to display
     */
    public void updateWindow(NeuralNetwork network){
        this.setTitle(JailBreakUIConstants.CAPTION_WINDOW+" - Neural Network");
        this.desktopPane.updateDesktop(network);
    }

    /** updates the window based on the object passed
     * @param layer a layer to display
     */    
    public void updateWindow(Layer layer){
        this.setTitle(JailBreakUIConstants.CAPTION_WINDOW+" - Layer");
        this.desktopPane.updateDesktop(layer);
    }    

    /** updates the window based on the object passed
     * @param neuron a neuron to display
     */    
    public void updateWindow(Neuron neuron){
        this.setTitle(JailBreakUIConstants.CAPTION_WINDOW+" - Neuron");
        this.desktopPane.updateDesktop(neuron);
    }    

    /** returns the item currently selected in the tree
     * @return item selected in the tree
     */       
    public Object getTreeSelection(){
        return(this.desktopPane.getTreeSelection());
    }    
    
     /** setProgress sets the caption and progress percent
      * @param statusMessage the status message to display
      * @param percentComplete the percent complete to display
      */
    public void setProgress(String statusMessage,int percentComplete){
        this.statusBar.setProgress(statusMessage,percentComplete);
    }    

     /** setProgess sets the caption and progress percent to zero
      * @param statusMessage the status message to display
      */
    public void setProgress(String statusMessage){
        this.setProgress(statusMessage,0);
    }        
    
    /** method invoked when the window is closed
     */
    public void closeWindow(){
    }
    
    /** actionListener receives events from the GUI
     * @param e ActionEvent received by UI
     */
     public void actionListener(final ActionEvent e){
     }    
    
     /** sendEvent override when creating a new instance of this object 
      * @param event the event to send to the parent class of this object
      */
    public void sendEvent(JailBreakEvent event){ 
    }

    /** receiveEvent receives JailBreakEvents from objects
      * @param event the event received
      */
    public void receiveActionEvent(JailBreakEvent event){ 
        /* send all events to the parent class */
        this.sendEvent(event);
    }
}