package com.huguesjohnson.jail.jailBreak;

/*
jailBreak - Package to launch Java Artificial Intelligence Library components
JailBreakObjectBrowserInternalFrame.java - Internal frame which displays tree to browse neural network or decision tree
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.lang.String;
import java.awt.BorderLayout;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.JButton;
import javax.swing.JInternalFrame;
import javax.swing.JScrollPane;
import javax.swing.JToolBar;
import com.huguesjohnson.jail.jailBreak.JailBreakNetworkTree;
import com.huguesjohnson.jail.jailBreak.JailBreakUIConstants;
import com.huguesjohnson.jail.jailBreak.event.JailBreakEvent;
import com.huguesjohnson.jail.neuralNetwork.BackPropagationNetwork;
import com.huguesjohnson.jail.neuralNetwork.Layer;
import com.huguesjohnson.jail.neuralNetwork.NeuralNetwork;
import com.huguesjohnson.jail.neuralNetwork.Neuron;

/** JailBreakObjectBrowserInternalFrame Internal frame which displays tree to browse neural network or decision tree
 * @author Hugues Johnson
 */
public class JailBreakObjectBrowserInternalFrame extends JInternalFrame implements ActionListener{

    /** the path to the folder containing images for current theme */
    private String resourcePath;

    /** the path to the folder containing default images */
    private String defaultResourcePath;
    
    /** reference to insert button */
    private JButton insertButton;
    
    /** reference to remove button */
    private JButton removeButton;

    /** reference to the tree */
    private JailBreakNetworkTree tree;
    
    /** Creates new JailBreakObjectBrowserInternalFrame
     * @param resourcePath path to the folder containing images for current theme 
     * @param defaultResourcePath path to the folder containing default images   
     */
    public JailBreakObjectBrowserInternalFrame(String resourcePath,String defaultResourcePath){
        super(JailBreakUIConstants.CAPTION_BROWSE_FRAME,JailBreakUIConstants.INTERNAL_FRAME_RESIZABLE,JailBreakUIConstants.INTERNAL_FRAME_CLOSABLE,JailBreakUIConstants.INTERNAL_FRAME_MAXIMIZABLE,JailBreakUIConstants.INTERNAL_FRAME_ICONIFIABLE);
        this.resourcePath=resourcePath;
        this.defaultResourcePath=defaultResourcePath;
        this.addComponents();
    }
    
    /** adds components to the frame
     */
    private void addComponents(){
        /* add the tree view */
        this.tree=new JailBreakNetworkTree(resourcePath,defaultResourcePath){ public void sendEvent(JailBreakEvent event){ receiveActionEvent(event);}};
        JScrollPane scrollPane=new JScrollPane(this.tree);
        this.getContentPane().add(scrollPane,BorderLayout.CENTER);
        /* add insert and remove buttons */
        this.insertButton=new JButton(JailBreakUIConstants.ACTION_INSERT);
        this.insertButton.setActionCommand(JailBreakUIConstants.ACTION_INSERT);
        this.insertButton.setEnabled(false);
        this.insertButton.addActionListener(this);
        this.removeButton=new JButton(JailBreakUIConstants.ACTION_REMOVE);
        this.removeButton.setActionCommand(JailBreakUIConstants.ACTION_REMOVE);
        this.removeButton.setEnabled(false);
        this.removeButton.addActionListener(this);
        JToolBar toolbar=new JToolBar();
        toolbar.add(this.insertButton);
        toolbar.add(this.removeButton);
        this.getContentPane().add(toolbar,BorderLayout.SOUTH);
    }
    
    /** updates the frame based on the object passed
     * @param network a neural network to display
     */
    public void updateFrame(NeuralNetwork network){
        if(network instanceof BackPropagationNetwork){
            this.tree.updateTree((BackPropagationNetwork)network);
        }
    }

    /** updates the frame based on the object passed
     * @param layer a layer to display
     */
    public void updateFrame(Layer layer){
    }
    
    /** updates the frame based on the object passed
     * @param neuron a neuron to display
     */
    public void updateFrame(Neuron neuron){
    }    

    /** returns the current tree selection
     * @return current tree selection
     */
    public Object getTreeSelection(){
        return(this.tree.getSelectedObject());
    }
    
    /** actionListener receives events from the GUI
     * @param e ActionEvent received by UI
     */
     public void actionPerformed(final ActionEvent e){
     }
    
     /** sendEvent override when creating a new instance of this object 
      * @param event the event to send to the parent class of this object
      */
    public void sendEvent(JailBreakEvent event){ 
    }

    /** receiveEvent receives JailBreakEvents from objects
      * @param event the event received
      */
    public void receiveActionEvent(JailBreakEvent event){ 
        /* send all events to the parent class */
        this.sendEvent(event);
    }    
}