package com.huguesjohnson.jail.jailBreak.event;

/*
jailBreak - Package to launch Java Artificial Intelligence Library components
JailBreakActionEvent.java - Generic GUI events
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.lang.Object;
import java.lang.String;
import java.lang.StringBuffer;
import com.huguesjohnson.jail.jailBreak.event.JailBreakEvent;

/**
 * class JailBreakActionEvent represents GUI actions
 * @author Hugues Johnson
 */
public final class JailBreakActionEvent extends JailBreakEvent{
    /** contains additional parameter for this action event, not all action events use a parameter */
    private String parameter;
    
    /** action command associated with this event */
    private String actionCommand;
    
    /** default constructor
     * @param actionCommand action command associated with this event
     */
    public JailBreakActionEvent(String actionCommand){
        super();
        this.actionCommand=actionCommand;
        this.parameter=null;
    }

    /** constructor
     * @param actionCommand action command associated with this event
     * @param parameter contains additional parameter for this action event, not all action events use a parameter
     */
    public JailBreakActionEvent(String actionCommand,String parameter){
        super();
        this.actionCommand=actionCommand;
        this.parameter=parameter;
    }
    
    /** setActionCommand sets the action command associated with the event
     * @param actionCommand the action command associated with this event
     */
    public final void setActionCommand(String actionCommand){
        this.actionCommand=actionCommand;
    }    
    
    /** setParameter sets the parameter associated with the event
     * @param parameter the parameter associated with this event
     */
    public final void setParameter(String parameter){
        this.parameter=parameter;
    }    

    /** getActionCommand retrieves the action command associated with the event
     * @return action command associated with this event
     */
    public final String getActionCommand(){
        return(this.actionCommand);
    }
    
    /** getParamter retrieves the parameter associated with the event
     * @return actionCommand associated with this event
     */
    public final String getParameter(){
        return(this.parameter);
    }    
    
    /** returns a string representation of the object
     * @return string representation of the object
     */
    public String toString(){
        StringBuffer tostring=new StringBuffer(super.toString());
        tostring.append("\nactionCommand="+this.actionCommand);
        tostring.append("\nparameter="+this.parameter);
        return(tostring.toString());
    }
}