package com.huguesjohnson.jail.jailBreak.event;

/*
jailBreak - Package to launch Java Artificial Intelligence Library components
JailBreakTreeSelectionEvent.java - represents a tree selection
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.lang.Object;
import java.lang.String;
import java.lang.StringBuffer;
import com.huguesjohnson.jail.jailBreak.event.JailBreakEvent;

/** class JailBreakTreeSelectionEvent represents a tree selection
 * @author Hugues Johnson
 */
public final class JailBreakTreeSelectionEvent extends JailBreakEvent{
    
    /** underlying object behind the selected node */
    private Object userObject;
    
    /** constructor
     * @param userObject the object behind the node that was selected
     */
    public JailBreakTreeSelectionEvent(Object userObject){
        super();
        this.userObject=userObject;
    }
    
    /** sets the object behind the node that was selected
     * @param userObject the object behind the node that was selected
     */
    public void setUserObject(Object userObject){
        this.userObject=userObject;
    }
    
    /** returns the object behind the node that was selected
     * @return the object behind the node that was selected
     */
    public Object getUserObject(){
        return(this.userObject);
    }
    
    /** returns a string representation of the object
     * @return string representation of the object
     */
    public String toString(){
        StringBuffer tostring=new StringBuffer(super.toString());
        tostring.append("userObject="+userObject.toString());
        return(tostring.toString());
    }
}