/*
jailBreak - Package to launch Java Artificial Intelligence Library components
JailBreakNewBackPropagationNetworkWizard.java - dialog to create a new backpropagation neural network
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

package com.huguesjohnson.jail.jailBreak.wizard;

import java.awt.Dimension;
import java.awt.Frame;
import java.awt.GridLayout;
import java.awt.Rectangle;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusEvent;
import java.lang.Double;
import java.lang.Integer;
import java.lang.String;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFormattedTextField;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import com.huguesjohnson.jail.jailBreak.JailBreakUIConstants;
import com.huguesjohnson.jail.jailBreak.event.JailBreakActionEvent;

/** dialog to create a new backpropagation neural network
 * @author  Hugues Johnson
 */
public class JailBreakNewBackPropagationNetworkWizard extends JDialog implements ActionListener{
    
    /** the path to the folder containing images for current theme */
    private String resourcePath;

    /** the path to the folder containing default images */
    private String defaultResourcePath;

    /** the action selected by the user when the dialog is exited */
    private JailBreakActionEvent exitAction;    
    
    /* begin formatted text fields to hold values entered by user */
    /** formatted text field to enter input layer size */
    JFormattedTextField inputLayerSizeField;
    /** formatted text field to enter hidden layer size */
    JFormattedTextField hiddenLayerSizeField;
    /** formatted text field to enter ouyput layer size */
    JFormattedTextField outputLayerSizeField;
    /** formatted text field to enter input size */
    JFormattedTextField inputSizeField;
    /** formatted text field to enter punish rate */
    JFormattedTextField punishRateField;
    /** formatted text field to enter reward rate */
    JFormattedTextField rewardRateField;
    /** formatted text field to enter error threshold */
    JFormattedTextField errorThresholdField;
    /** formatted text field to enter minimum weight */
    JFormattedTextField minWeightField;
    /** formatted text field to enter maximum weight */
    JFormattedTextField maxWeightField;
    /* end formatted text fields to hold values entered by user */
    
    /** text area to display help */
    JLabel helpText;
    
    /** constructor
     * @param parent the parent frame to this wizard
     * @param resourcePath the path to directory containing images for this dialog
     * @param defaultResourcePath path to the folder containing default images   
     */
    public JailBreakNewBackPropagationNetworkWizard(Frame parent,String resourcePath,String defaultResourcePath){
        super(parent,"New Backpropagation Neural Network",true);
        this.resourcePath=resourcePath;
        this.defaultResourcePath=defaultResourcePath;
        this.exitAction=new JailBreakActionEvent(JailBreakUIConstants.ACTION_EXIT);
        /* size the window */
        this.setSize(320,260);
        /* add components */
        this.addComponents();
        /* center the window */
        Dimension screenDimension=Toolkit.getDefaultToolkit().getScreenSize();
        Rectangle windowDimension=this.getBounds();
        this.setLocation((screenDimension.width-windowDimension.width)/2,(screenDimension.height-windowDimension.height)/2);        
    }    

    /** adds components to the dialog
     */
    private void addComponents(){
        /* create help text.. added later in this routine but created first to avoid some compiler warnings */
        this.helpText=new JLabel("<html>Create a new Backpropagation neural network</html>");
        this.helpText.setAlignmentY(1.0F);
        /* set layout for this dialog */
        //this.getContentPane().setLayout(new GridLayout(10,2));
        this.getContentPane().setLayout(new BoxLayout(this.getContentPane(),BoxLayout.Y_AXIS));
        JPanel panel=new JPanel(new GridLayout(9,2));
        /* input layer size */
        panel.add(new JLabel("Input Layer Size: "));
        this.inputLayerSizeField=new JFormattedTextField(new Integer(JailBreakUIConstants.BPNN_DEFAULT_INPUT_LAYER_SIZE)){
            protected void processFocusEvent(FocusEvent focusEvent){
                super.processFocusEvent(focusEvent);
                if(focusEvent.getID()==FocusEvent.FOCUS_GAINED){
                    helpText.setText("<html><i>Input Layer Size</i><br>Data Type: Integer<br>The number of neurons in the input layer.<br>Should be larger than the hidden and output layers.</html>");
                }
            }
        };
        this.inputLayerSizeField.setFocusLostBehavior(JFormattedTextField.COMMIT_OR_REVERT);
        panel.add(this.inputLayerSizeField);
        /* hidden layer size */
        panel.add(new JLabel("Hidden Layer Size: "));
        this.hiddenLayerSizeField=new JFormattedTextField(new Integer(JailBreakUIConstants.BPNN_DEFAULT_HIDDEN_LAYER_SIZE)){
            protected void processFocusEvent(FocusEvent focusEvent){
                super.processFocusEvent(focusEvent);
                if(focusEvent.getID()==FocusEvent.FOCUS_GAINED){
                    helpText.setText("<html><i>Hidden Layer Size</i><br>Data Type: Integer<br>The number of neurons in the hidden layer.<br>Should be smaller than the input layer and larger than the output layer.</html>");
                }
            }
        };
        this.hiddenLayerSizeField.setFocusLostBehavior(JFormattedTextField.COMMIT_OR_REVERT);
        panel.add(this.hiddenLayerSizeField);
        /* output layer size */
        panel.add(new JLabel("Output Layer Size: "));
        this.outputLayerSizeField=new JFormattedTextField(new Integer(JailBreakUIConstants.BPNN_DEFAULT_OUTPUT_LAYER_SIZE)){
            protected void processFocusEvent(FocusEvent focusEvent){
                super.processFocusEvent(focusEvent);
                if(focusEvent.getID()==FocusEvent.FOCUS_GAINED){
                    helpText.setText("<html><i>Output Layer Size</i><br>Data Type: Integer<br>The number of neurons in the output layer.<br>Should be smaller than the hidden and output layers.</html>");
                }
            }
        };
        this.outputLayerSizeField.setFocusLostBehavior(JFormattedTextField.COMMIT_OR_REVERT);
        panel.add(this.outputLayerSizeField);
        /* input size */
        panel.add(new JLabel("Input Size: "));
        this.inputSizeField=new JFormattedTextField(new Integer(JailBreakUIConstants.BPNN_DEFAULT_INPUT_SIZE)){
            protected void processFocusEvent(FocusEvent focusEvent){
                super.processFocusEvent(focusEvent);
                if(focusEvent.getID()==FocusEvent.FOCUS_GAINED){
                    helpText.setText("<html><i>Input Size</i><br>Data Type: Integer<br>The number of inputs being fed to the input layer.</html>");
                }
            }
        };
        this.inputSizeField.setFocusLostBehavior(JFormattedTextField.COMMIT_OR_REVERT);
        panel.add(this.inputSizeField);
        /* punish rate */
        panel.add(new JLabel("Punish Rate: "));
        this.punishRateField=new JFormattedTextField(new Double(JailBreakUIConstants.BPNN_DEFAULT_PUNISH_RATE)){
            protected void processFocusEvent(FocusEvent focusEvent){
                super.processFocusEvent(focusEvent);
                if(focusEvent.getID()==FocusEvent.FOCUS_GAINED){
                    helpText.setText("<html><i>Punish Rate</i><br>Data Type: Double<br>The rate that link weights between neurons are punished if they are causing incorrect output.</html>");
                }
            }
        };
        this.punishRateField.setFocusLostBehavior(JFormattedTextField.COMMIT_OR_REVERT);
        panel.add(this.punishRateField);
        /* reward rate */
        panel.add(new JLabel("Reward Rate: "));
        this.rewardRateField=new JFormattedTextField(new Double(JailBreakUIConstants.BPNN_DEFAULT_REWARD_RATE)){
            protected void processFocusEvent(FocusEvent focusEvent){
                super.processFocusEvent(focusEvent);
                if(focusEvent.getID()==FocusEvent.FOCUS_GAINED){
                    helpText.setText("<html><i>Reward Rate</i><br>Data Type: Double<br>The rate that link weights between neurons are rewarded if they are causing correct output.</html>");
                }
            }
        };
        this.rewardRateField.setFocusLostBehavior(JFormattedTextField.COMMIT_OR_REVERT);
        panel.add(this.rewardRateField);
        /* error threshold */
        panel.add(new JLabel("Error Threshold: "));
        this.errorThresholdField=new JFormattedTextField(new Double(JailBreakUIConstants.BPNN_DEFAULT_ERROR_THRESHOLD)){
            protected void processFocusEvent(FocusEvent focusEvent){
                super.processFocusEvent(focusEvent);
                if(focusEvent.getID()==FocusEvent.FOCUS_GAINED){
                    helpText.setText("<html><i>Error Theshold</i><br>Data Type: Double<br>The maximum error allowed by a neuron before training stops for that neuron in a given training iteration.</html>");
                }
            }
        };
        this.errorThresholdField.setFocusLostBehavior(JFormattedTextField.COMMIT_OR_REVERT);
        panel.add(this.errorThresholdField);
        /* minimum weight */
        panel.add(new JLabel("Minimum Initial Link Weight: "));
        this.minWeightField=new JFormattedTextField(new Double(JailBreakUIConstants.BPNN_DEFAULT_MIN_WEIGHT)){
            protected void processFocusEvent(FocusEvent focusEvent){
                super.processFocusEvent(focusEvent);
                if(focusEvent.getID()==FocusEvent.FOCUS_GAINED){
                    helpText.setText("<html><i>Minimum Initial Link Weight</i><br>Data Type: Double<br>The smallest initial value a link weight can have.<br>Link weights are initially assigned a random value between the minimum and maximum weight settings.</html>");
                }
            }
        };
        this.minWeightField.setFocusLostBehavior(JFormattedTextField.COMMIT_OR_REVERT);
        panel.add(this.minWeightField);
        /* maximum weight */
        panel.add(new JLabel("Maximum Initial Link Weight: "));
        this.maxWeightField=new JFormattedTextField(new Double(JailBreakUIConstants.BPNN_DEFAULT_MAX_WEIGHT)){
            protected void processFocusEvent(FocusEvent focusEvent){
                super.processFocusEvent(focusEvent);
                if(focusEvent.getID()==FocusEvent.FOCUS_GAINED){
                    helpText.setText("<html><i>Maximum Initial Link Weight</i><br>Data Type: Double<br>The largest initial value a link weight can have.<br>Link weights are initially assigned a random value between the minimum and maximum weight settings.</html>");
                }
            }
        };
        this.maxWeightField.setFocusLostBehavior(JFormattedTextField.COMMIT_OR_REVERT);
        panel.add(this.maxWeightField);
        /* add panel holding all the formatted text fields and their labels */
        this.getContentPane().add(panel);
        /* add help area */
        panel=new JPanel();
        panel.setLayout(new BoxLayout(panel,BoxLayout.X_AXIS));
        panel.add(new JScrollPane(this.helpText));
        /* add ok and cancel buttons */
        JPanel buttonPanel=new JPanel();
        buttonPanel.setLayout(new GridLayout(2,1));
        JButton button=new JButton(JailBreakUIConstants.ACTION_OK);
        button.setActionCommand(JailBreakUIConstants.ACTION_OK);
        button.addActionListener(this);
        buttonPanel.add(button);
        button=new JButton(JailBreakUIConstants.ACTION_CANCEL);
        button.setActionCommand(JailBreakUIConstants.ACTION_CANCEL);
        button.addActionListener(this);
        buttonPanel.add(button);
        panel.add(buttonPanel);
        this.getContentPane().add(panel);        
    }

    /** returns the last action selected by the user
     * @return last action selected by user
     */
    public JailBreakActionEvent getExitActionEvent(){
        return(this.exitAction);
    }    
    
     /** occurs when a button is clicked
     * @param actionEvent the action received
     */    
    public void actionPerformed(ActionEvent actionEvent){
        String actionCommand=actionEvent.getActionCommand();
        if(actionCommand==JailBreakUIConstants.ACTION_OK){
            this.exitAction=new JailBreakActionEvent(JailBreakUIConstants.ACTION_OK);
            this.dispose();
        } else if(actionCommand==JailBreakUIConstants.ACTION_CANCEL){
            this.exitAction=new JailBreakActionEvent(JailBreakUIConstants.ACTION_EXIT);
            this.dispose();
        }
    }

    /** returns the value of the input layer size field
     * @return value of input layer size field
     */
    public int getInputLayerSize(){
        return(((Integer)this.inputLayerSizeField.getValue()).intValue());
    }
    
    /** returns the value of the hidden layer size field
     * @return value of hidden layer size field
     */
    public int getHiddenLayerSize(){
        return(((Integer)this.hiddenLayerSizeField.getValue()).intValue());
    }

    /** returns the value of the output layer size field
     * @return value of output layer size field
     */
    public int getOutputLayerSize(){
        return(((Integer)this.outputLayerSizeField.getValue()).intValue());
    }

    /** returns the value of the input size field
     * @return value of input size field
     */
    public int getInputSize(){
        return(((Integer)this.inputSizeField.getValue()).intValue());
    }

    /** returns the value of the punish rate field
     * @return value of the punish rate field
     */
    public double getPunishRate(){
        return(((Double)this.punishRateField.getValue()).doubleValue());
    }
    
    /** returns the value of the reward rate field
     * @return value of the reward rate field
     */
    public double getRewardRate(){
        return(((Double)this.rewardRateField.getValue()).doubleValue());
    }

    /** returns the value of the error threshold field
     * @return value of the error threshold field
     */
    public double getErrorThreshold(){
        return(((Double)this.errorThresholdField.getValue()).doubleValue());
    }

    /** returns the value of the minimum weight field
     * @return value of minimum weight field
     */
    public double getMinWeight(){
        return(((Double)this.minWeightField.getValue()).doubleValue());
    }
    
    /** returns the value of the maximum weight field
     * @return value of maximum weight field
     */
    public double getMaxWeight(){
        return(((Double)this.maxWeightField.getValue()).doubleValue());
    }
    
}