package com.huguesjohnson.jail.jdt;

/*
Jdt (Java Decision Tree) - Package to create and display a decision tree
Attribute.java - decision tree attribute
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.io.Serializable;
import java.lang.Object;
import java.lang.String;

/** class Attribute
 * @author Hugues Johnson
 */
public class Attribute extends Object implements Serializable{
    /* private shared members */

    /** name of the attribute */    
    private String name;
    /** gain of the attribute, stored as double to allow very high precision to avoid ties when comparing gain between attributes */
    private double gain; 
    
    /** constructor
     * @param name name of the attribute
     * @param gain gain of the attribute
     */
    public Attribute(String name, double gain){
        this.name=name;
        this.gain=gain;
    }
    
    /** constructor
     * sets gain of attribute to default value of 0.0D
     * @param name name of attribute
     */
    public Attribute(String name){
        this.name=name;
        this.gain=0.0D;
    }
    
    /** retrieves name of attribute
     * @return name
     */
    public String getName(){
        return(this.name);
    }
    
    /** retrieves gain of attribute
     * @return gain
     */
    public double getGain(){
        return(this.gain);
    }
    
    /** sets name of attribute
     * @param name new name of attribute
     */
    public void setName(String name){
        this.name=name;
    }
    
    /** sets gain of attribute
     * @param gain new gain of attribute
     */
    public void setGain(double gain){
        this.gain=gain;
    }
    
    /** returns a string representation of the object
     * @return string representation of the object
     */
    public String toString(){
        String tostring=new String(this.getClass().getName());
        tostring+="\nname="+this.name;
        tostring+="\ngain="+this.gain;
        return(tostring);
    }
}