package com.huguesjohnson.jail.jdt;

/*
Jdt (Java Decision Tree) - Package to create and display a decision tree
DataInstance.java - instance of training or testing data
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.io.Serializable;
import java.lang.Object;
import java.lang.String;

/** class JdtDataInstance, internal representation for stored data
 */
public class DataInstance extends Object implements Serializable{
    /* private shared members */
    /** array of elements stored by data instance */    
    private double data[];
    /** classification for the instance of data */    
    private String classification;
    /** number of elements of stored in data instance */    
    private int elementCount;
    
    /** constructor
     * @param elementCount how many elements are to be stored
     */
    public DataInstance(int elementCount){
        if(elementCount>0){
            this.elementCount=elementCount;
            this.data=new double[this.elementCount];
        } else{
            this.elementCount=0;
        }
        this.classification="unclassified";
    }

    /** sets an element in the data instance
     * @param index index of data element
     * @param value value of data
     */    
    public void setData(int index,double value){
        if(index>=0&&index<this.elementCount){
            this.data[index]=value;
        }
    }
    
    /** retrieves an element of data
     * @param index index of data element
     * @return element of data at index, 0 if invalid index
     */    
    public double getData(int index){
        if(index>=0&&index<this.elementCount){
            return(this.data[index]);
        } else{
            return(0.0D);
        }
    }
    
    /** sets the class for the data
     * @param classification new classification
     */
    public void setClassification(String classification){
        this.classification=classification;
    }
    
    /** retreives class for the data
     * @return classification for data
     */
    public String getClassification(){
        return(this.classification);
    }
    
     /** toString returns a string representation of the object
     * @return string representation of the object
     */
    public String toString(){
        String tostring=new String(this.getClass().getName());
        tostring+="\nelementCount="+this.elementCount;
        int length=this.data.length;
        tostring+="\ndata.length="+length;
        for(int index=0;index<length;index++){
            tostring+=this.data[index]+" ";
        }
        tostring+="\nclassification="+this.classification;
        return(tostring);
    }
}