package com.huguesjohnson.jail.jdt;

/*
Jdt (Java Decision Tree) - Package to create and display a decision tree
JdtUIFilePanelBox.java - a single field to display within a file panel
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.lang.String;
import java.lang.System;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JPanel;
import javax.swing.JTextField;
import com.huguesjohnson.jail.jdt.JdtUIConstants;

/** class JdtUIFilePanelBox
 * @author Hugues Johnson
 */
public class JdtUIFilePanelBox extends JPanel implements ActionListener{
    /** the caption of the panel */
    private String caption;
    
    /** the last directory opened by the browse button */
    private static String lastDir;
    
    /** value of the panel */
    private JTextField textField;
    
    /** constructor
     * @param caption the caption of the panel
     */
    public JdtUIFilePanelBox(String caption){
        super();
        this.caption=caption;
        this.lastDir=System.getProperty("user.dir")+File.separator;
        this.addComponents();
    }
    
    /** add components to the panel
     */
    private void addComponents(){
        this.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEmptyBorder(),this.caption));
        this.setLayout(new BorderLayout());
        this.setMaximumSize(new Dimension(1000,50));
        this.textField=new JTextField();
        this.textField.setColumns(20);
        this.add(this.textField,BorderLayout.CENTER);
        JButton button=new JButton("Browse..");
        button.setActionCommand("browse");
        button.addActionListener(this);
        this.add(button,BorderLayout.EAST);
    }
    
    /** sets the path of the text area
     * @param filePath new text
     */
    public void setFilePath(String filePath){
        if(this.textField!=null){
            this.textField.setText(filePath);
        }
    }
    
    /** returns the current file path
     * @return current file path
     */
    public String getFilePath(){
        if(this.textField!=null){
            return(this.textField.getText());
        } else{
            return(null);
        }
    }
    
    /** browses for a file and saves the last visited path
     */
    private void browseForFile(){
        /* set up file chooser */
        final JFileChooser fc=new JFileChooser(this.lastDir);
        fc.setDialogTitle("Open File");
        int returnValue=fc.showOpenDialog(this.getParent());
        if(returnValue==fc.APPROVE_OPTION){
            this.lastDir=fc.getCurrentDirectory().getPath();
            if(!this.lastDir.endsWith(File.separator)){
                this.lastDir=this.lastDir+File.separator;
            }
            this.setFilePath(this.lastDir+fc.getSelectedFile().getName());
        }
    }
    
     /** receives swing events
     * @param e the event received
     */
    public void actionPerformed(ActionEvent e){
        if(e.getActionCommand().equals("browse")){
            this.browseForFile();
        }
    }
    
    /** returns a string representation of the object
     * @return string representation of the object
     */
    public String toString(){
        String tostring=new String(super.toString());
        tostring+="\ncaption="+this.caption;
        tostring+="\nlastDir="+this.lastDir;
        tostring+="\ntextField="+this.textField.toString();
        return(tostring);
    }    
}