package com.huguesjohnson.jail.jdt;

/*
Jdt (Java Decision Tree) - Package to create and display a decision tree
JdtUINavigatePanel.java - swing panel used to navigate through the UI
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.lang.String;
import javax.swing.BoxLayout;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JPanel;
import com.huguesjohnson.jail.jdt.JdtUIConstants;

/** JdtUINavigatePanel
 * @author Hugues Johnson
 */
public class JdtUINavigatePanel extends JPanel implements ActionListener{
    /** directory containing images for this panel */
    private String resourcePath;
    
    /** constructor
     * @param resourcePath directory containing images
     */
    public JdtUINavigatePanel(String resourcePath){
        super();
        this.resourcePath=resourcePath;
        this.addComponents();
    }
    
    /** adds components to the panel
     */
    private void addComponents(){
        JButton button;
        this.setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));
        /* add Jdt button */
        button=new JButton(new ImageIcon(this.resourcePath+"jdt.gif"));
        button.setActionCommand(JdtUIConstants.ACTION_SET_PANE_WELCOME);
        button.setToolTipText(JdtUIConstants.TOOLTIP_JDT_BUTTON);
        button.setBorderPainted(false);
        button.addActionListener(this);
        this.add(button);
        /* add files button */
        button=new JButton(new ImageIcon(this.resourcePath+"files.gif"));
        button.setActionCommand(JdtUIConstants.ACTION_SET_PANE_FILE);
        button.setToolTipText(JdtUIConstants.TOOLTIP_FILES_BUTTON);
        button.setBorderPainted(false);
        button.addActionListener(this);
        this.add(button);
        /* add run button */
        button=new JButton(new ImageIcon(this.resourcePath+"run.gif"));
        button.setActionCommand(JdtUIConstants.ACTION_SET_PANE_RUN);
        button.setToolTipText(JdtUIConstants.TOOLTIP_RUN_BUTTON);
        button.setBorderPainted(false);
        button.addActionListener(this);
        this.add(button);
        /* add tree button */
        button=new JButton(new ImageIcon(this.resourcePath+"tree.gif"));
        button.setActionCommand(JdtUIConstants.ACTION_SET_PANE_TREE);
        button.setToolTipText(JdtUIConstants.TOOLTIP_TREE_BUTTON);
        button.setBorderPainted(false);
        button.addActionListener(this);
        this.add(button);
    }
    
    /** receives swing events
     * @param e the event received
     */
    public void actionPerformed(ActionEvent e){
        /* override this */
    }
    
    /** returns a string representation of the object
     * @return string representation of the object
     */
    public String toString(){
        String tostring=new String(super.toString());
        tostring+="\nresourcePath="+this.resourcePath;
        return(tostring);
    }
}