package com.huguesjohnson.jail.jdt;

/*
Jdt (Java Decision Tree) - Package to create and display a decision tree
JdtUIRunPanel.java - swing panel to set decision run options and start build tree process
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import com.huguesjohnson.jail.jdt.JdtUIConstants;

/** JdtUIRunPanel
 * @author Hugues Johnson
 */
public class JdtUIRunPanel extends JPanel implements ActionListener{
    /** test training data checkbox */
    private JCheckBox checkTestTrainData;
    
    /** test test data checkbox */
    private JCheckBox checkTestTestData;
    
    /** create execution log checkbox */
    private JCheckBox checkCreateExecutionLog;
    
    /** create report checkbox */
    private JCheckBox checkCreateReport;
    
    /** run button */
    private JButton runButton;
    
    /** constructor
     */
    public JdtUIRunPanel(){
        this.addComponents();
    }

    /** adds components to the panel
     */
    private void addComponents(){
        this.setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));
        /* add run panel */
        JPanel runPanel=new JPanel();
        runPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEmptyBorder(),"Run"));
        runPanel.setLayout(new BoxLayout(runPanel,BoxLayout.Y_AXIS));
        this.checkTestTrainData=new JCheckBox(JdtUIConstants.CAPTION_CHECKBOX_TRAINDATA);        
        runPanel.add(this.checkTestTrainData);
        this.checkTestTestData=new JCheckBox(JdtUIConstants.CAPTION_CHECKBOX_TESTDATA);        
        runPanel.add(this.checkTestTestData);
        this.checkCreateReport=new JCheckBox(JdtUIConstants.CAPTION_CHECKBOX_CREATEREPORT);        
        runPanel.add(this.checkCreateReport);
        this.checkCreateExecutionLog=new JCheckBox(JdtUIConstants.CAPTION_CHECKBOX_CREATELOG);        
        runPanel.add(this.checkCreateExecutionLog);
        this.runButton=new JButton(JdtUIConstants.CAPTION_BUTTON_BUILD);
        this.runButton.setActionCommand(JdtUIConstants.ACTION_RUN);
        this.runButton.addActionListener(this);
        runPanel.add(this.runButton);
        this.add(runPanel);
    }
    
    /** set the value and active status of the test training data checkbox
     * @param checked whether or not the checkbox is checked
     * @param enabled whether or not the checkbox is enabled
     */
    public void setTestTrainDataCheckbox(boolean checked,boolean enabled){
        if(this.checkTestTrainData!=null){
            this.checkTestTrainData.setSelected(checked);
            this.checkTestTrainData.setEnabled(enabled);
        }
    }

    /** set the value and active status of the test test data checkbox
     * @param checked whether or not the checkbox is checked
     * @param enabled whether or not the checkbox is enabled
     */
    public void setTestTestDataCheckbox(boolean checked,boolean enabled){
        if(this.checkTestTestData!=null){
            this.checkTestTestData.setSelected(checked);
            this.checkTestTestData.setEnabled(enabled);
        }
    }    

    /** set the value and active status of the create execution log checkbox
     * @param checked whether or not the checkbox is checked
     * @param enabled whether or not the checkbox is enabled
     */
    public void setCreateExecutionLogCheckbox(boolean checked,boolean enabled){
        if(this.checkCreateExecutionLog!=null){
            this.checkCreateExecutionLog.setSelected(checked);
            this.checkCreateExecutionLog.setEnabled(enabled);
        }
    }

    /** set the value and active status of the create report checkbox
     * @param checked whether or not the checkbox is checked
     * @param enabled whether or not the checkbox is enabled
     */    
    public void setCreateReportCheckbox(boolean checked,boolean enabled){
        if(this.checkCreateReport!=null){
            this.checkCreateReport.setSelected(checked);
            this.checkCreateReport.setEnabled(enabled);
        }
    }    
    
    /** returns the value of the test training data checkbox
     * @return value of the checkbox
     */
    public boolean getTestTrainDataCheckboxValue(){
        return(this.checkTestTrainData.isSelected());
    }

    /** returns the value of the test test data checkbox
     * @return value of the checkbox
     */    
    public boolean getTestTestDataCheckboxValue(){
        return(this.checkTestTestData.isSelected());
    }
    
    /** returns the value of the create log checkbox
     * @return value of the checkbox
     */    
    public boolean getCreateExecutionCheckboxValue(){
        return(this.checkCreateExecutionLog.isSelected());
    }

    /** returns the value of the create report checkbox
     * @return value of the checkbox
     */    
    public boolean getCreateReportCheckboxValue(){
        return(this.checkCreateReport.isSelected());
    }
    
    /** sets the active status of the run button
     * @param enabled whether or not the run button is enabled
     */
    public void setRunButtonEnabled(boolean enabled){
        if(this.runButton!=null){
            this.runButton.setEnabled(enabled);
        }
    }
    
    /** receives swing events
     * @param e the event received
     */
    public void actionPerformed(ActionEvent e){
        /* override this */
    }

    /** returns a string representation of the object
     * @return string representation of the object
     */
    public String toString(){
        String tostring=new String(super.toString());
        tostring+="\ncheckCreateExecutionLog="+this.checkCreateExecutionLog.toString();
        tostring+="\ncheckTestTestData="+this.checkTestTestData.toString();
        tostring+="\ncheckTestTrainData="+this.checkTestTrainData.toString();
        return(tostring);
    }    
}